local L = AceLibrary("AceLocale-2.2"):new("Depot")

Depot = AceLibrary("AceAddon-2.0"):new(
	"FuBarPlugin-2.0",
	"AceConsole-2.0",
	"AceEvent-2.0",
	"AceDB-2.0"
)

-- ---------------------------------------------------------------------------------
-- options
-- ---------------------------------------------------------------------------------
local options = { 
    type='group',
    args = {
		height = {
            type = 'range', min = 50, max = 300, step = 1,
            name = L["Height"],
            desc = L["Set height of the bottom bar"],
           	usage = L["Enter value"],
            get = "GetHeight",
            set = "SetHeight",
            order = 1,
        },
        width = {
            type = 'range', min = 50, max = 1800, step = 1,
            name = L["Width"],
            desc = L["Set width of the bottom bar"],
           	usage = L["Enter value"],
            get = "GetWidth",
            set = "SetWidth",
            order = 2,
        },
        gradient = {
            type = 'range', min = 1, max = 300, step = 1,
            name = L["Gradient"],
            desc = L["Set gradient of the bottom bar"],
           	usage = L["Enter value"],
            get = "GetGradient",
            set = "SetGradient",
            order = 300,
        },
        fcolor = {
            type = "color",
            hasAlpha = true,
            name = L["Frame color"],
            desc = L["Set color of the frame"],
            usage = L["Choose color"],
            get = "GetBackdropColor",
            set = "SetBackdropColor",
            order = 301,
        },
        bcolor = {
            type = "color",
            hasAlpha = true,
            name = L["Border color"],
            desc = L["Set color of the border"],
            usage = L["Choose color"],
            get = "GetBackdropBorderColor",
            set = "SetBackdropBorderColor",
            order = 302,
        },
	},
}

-- ---------------------------------------------------------------------------------
-- registrations
-- ---------------------------------------------------------------------------------
Depot:RegisterChatCommand({"/depot", "/dt"}, options)
Depot:RegisterDB("DepotDB", "DepotCharDB")
Depot:RegisterDefaults(
		"profile", 
		{
    		height = 125,
    		width = 1800,
    		gradient = 50,
    		BackdropR = 0,
    		BackdropG = 0,
    		BackdropB = 0,
    		BackdropA = 1,
    		BackdropBorderR = 0,
    		BackdropBorderG = 0,
    		BackdropBorderB = 0,
    		BackdropBorderA = 1,
		} 
)

-- ---------------------------------------------------------------------------------
-- FuBar
-- ---------------------------------------------------------------------------------
Depot.OnMenuRequest = options
Depot.hasIcon = "Interface\\AddOns\\Depot\\icon"
Depot.hasNoColor = true
Depot.independentProfile = true
Depot.hideWithoutStandby = true

-- ---------------------------------------------------------------------------------
-- functions for the options
-- ---------------------------------------------------------------------------------
function Depot:GetHeight()
	return self.db.profile.height
end

function Depot:SetHeight(newValue)
	self.db.profile.height = newValue
	self.depotframe:SetHeight(self.db.profile.height)
	self.depotframegradient:SetHeight(self.db.profile.gradient)
end

function Depot:GetWidth()
	return self.db.profile.width
end

function Depot:SetWidth(newValue)
	self.db.profile.width = newValue
	self.depotframe:SetWidth(self.db.profile.width)
	self.depotframegradient:SetWidth(self.db.profile.width - 10)
end

function Depot:GetGradient()
	return self.db.profile.gradient
end

function Depot:SetGradient(newValue)
	self.db.profile.gradient = newValue
	self.depotframegradient:SetHeight(self.db.profile.gradient)
end

function Depot:GetBackdropColor()
    return self.db.profile.BackdropR, self.db.profile.BackdropG, self.db.profile.BackdropB, self.db.profile.BackdropA
end

function Depot:SetBackdropColor(r, g, b, a)
    self.db.profile.BackdropR, self.db.profile.BackdropG, self.db.profile.BackdropB, self.db.profile.BackdropA = r, g, b, a
    self.depotframe:SetBackdropColor(self:GetBackdropColor())
end

function Depot:GetBackdropBorderColor()
    return self.db.profile.BackdropBorderR, self.db.profile.BackdropBorderG, self.db.profile.BackdropBorderB, self.db.profile.BackdropBorderA
end

function Depot:SetBackdropBorderColor(r, g, b, a)
    self.db.profile.BackdropBorderR, self.db.profile.BackdropBorderG, self.db.profile.BackdropBorderB, self.db.profile.BackdropBorderA = r, g, b, a
    self.depotframe:SetBackdropBorderColor(self:GetBackdropBorderColor())
end

-- ---------------------------------------------------------------------------------
-- functions
-- ---------------------------------------------------------------------------------

function Depot:OnInitialize()
	self:CreateDepotFrame(frame)
	self:Print(L["Depot loaded successfully!"])
end

function Depot:OnEnable()
    self.depotframe:Show()
end

function Depot:OnDisable()
    self.depotframe:Hide()
end

function Depot:CreateDepotFrame(frame)
	local frame = CreateFrame("Frame", DepotFrame, UIParent)
	
	frame:SetWidth(self.db.profile.width)
	frame:SetHeight(self.db.profile.height)
	frame:SetBackdrop({
		bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
		insets = {left = 4, right = 4, top = 4, bottom = 4},
	})
	frame:SetBackdropColor(self:GetBackdropColor())
	frame:SetBackdropBorderColor(self:GetBackdropBorderColor())
	frame:EnableMouse(false)
	frame:SetMovable(false)
	frame:ClearAllPoints()
	frame:SetPoint("BOTTOM", UIParent, "BOTTOM", 0, -10)
	frame:SetFrameStrata("BACKGROUND")
	
	frame.gradient = frame:CreateTexture(nil, "BORDER")
	frame.gradient:SetWidth(self.db.profile.width - 10)
	frame.gradient:SetHeight(self.db.profile.gradient)
	frame.gradient:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	frame.gradient:SetPoint("TOP", frame, "TOP", 0, -4)
	frame.gradient:SetBlendMode("ADD")
	frame.gradient:SetGradientAlpha("VERTICAL", .1, .1, .1, 0, .25, .25, .25, .5)
	
	self.depotframe = frame
	self.depotframegradient = frame.gradient
end
